﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using Infragistics.Controls.Editors;

namespace WpfApplication3
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        ObservableCollection<Flag> items = new ObservableCollection<Flag>();
        public MainWindow()
        {
            InitializeComponent();
            items.Add(new Flag { Name = "item1", Value = true, IsChecked = false });
            items.Add(new Flag { Name = "item2", Value = true, IsChecked = false });
            items.Add(new Flag { Name = "item3", Value = false, IsChecked = true });
            items.Add(new Flag { Name = "item4", Value = true, IsChecked = false });
            xamComboEditor.ItemsSource = items;
            sharedEditor.ItemsSource = items;
        }

        #region WPF ONLY EDITOR

        private void xamComboEditor_DropDownClosed(object sender, RoutedEventArgs e)
        {
            xamComboEditor.Text = "";
            foreach (Flag f in items)
            {
                if (f.IsChecked)
                {
                    xamComboEditor.Text += f.Name+"|";
                }
            }
        }

        private void OnPreviewKeyDown(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Space)
            {
                // check to see if an item is highlighted
                for (int i = 0; i < items.Count; i++)
                {
                    ComboBoxItem cbi = 
                        (ComboBoxItem)xamComboEditor.ComboBox.ItemContainerGenerator.ContainerFromIndex(i);

                    if (cbi.IsHighlighted)
                    {
                        items[i].IsChecked = !items[i].IsChecked;

                        e.Handled = true;
                    }
                }
            }
        }

        #endregion

        #region SHARED EDITOR

        private void sharedEditor_PreviewKeyDown(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Space)
            {
                foreach (ComboEditorItem item in sharedEditor.Items)
                {
                    if (item.IsFocused)
                    {
                        item.IsSelected = true;

                        e.Handled = true;
                    }
                }
            }
        }

        #endregion
    }

    public class Flag : INotifyPropertyChanged
    {
        public string Name { get; set; }
        public bool Value { get; set; }
        private bool isChecked;
        public bool IsChecked
        {
            get { return isChecked; }
            set { isChecked = value; OnPropertyChanged("IsChecked"); }
        }

        public Flag() { }
        public override string ToString()
        {
            return Name;
        }


        #region INotifyPropertyChanged Implementation
        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        protected void SetProperty<T>(ref T field, T value, string propertyName)
        {
            field = value;
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion
    }

    //public class Flags : ObservableCollection<Flag>
    //{
    //    private string selected;
    //    public string Selected
    //    {
    //        get { return selected; }
    //        set
    //        {
    //            selected = value;
    //            OnPropertyChanged(new PropertyChangedEventArgs("Selected"));
    //        }
    //    }

    //    public Flags() { }

    //    public void Update()
    //    {
    //        StringBuilder sb = new StringBuilder();
    //        foreach (Flag f in this)
    //        {
    //            sb.Append(this.Where(x => x.IsChecked).Select(x => x.Name)).Append("|");
    //        }
    //        //this.Where(x => x.IsChecked).Select(x => x.Name).Run(s => sb.Append(s).Append("|"));
    //        if (sb.Length > 0)
    //            sb.Remove(sb.Length - 1, 1);
    //        Selected = sb.ToString();
    //    }
    //    protected override void InsertItem(int index, Flag item)
    //    {
    //        item.Parent = this;
    //        base.InsertItem(index, item);
    //    }
    //}
}
